@@ -1,3 +1,3 @@
 from.getAStockCodeApi import *
-from.getHKFinanceData import *。
+from.getHKFinanceData import *
 from.common import *
\ No newline at end of file
